@@ -1,4 +1,6 @@
 {- |
+/RECOMMENDATION/: Use "Data.Generics.Uniplate.Operations" instead.
+
 This is the main Uniplate module, which defines all the essential operations
 in a Haskell 98 compatible manner.
 
@@ -73,7 +75,7 @@ uniplateList x = (c, b . d)
 --
 -- This method is often combined with a list comprehension, for example:
 --
--- > vals x = [Val i | i <- universe x]
+-- > vals x = [i | Val i <- universe x]
 universe :: Uniplate on => on -> [on]
 universe x = builder f
     where
